<?php

/**
 * Diese Datei enthält ein Beispiel-Skript zur Einholung einer Bonitätsauskunft über mediafinanz mit PHP. 
 + Es wird hierbei der Bürgel Service mit dem Produkt "ConCheck RealTime" für Privatpersonenauskünfte verwendet.
 * Das Skript hat lediglich exemplarischen Charakter und dient keinesfalls als vollständige Funktions-Referenz!
 * Die SOAP-Funktionalität steht nur dann zur Verfügung, wenn PHP mit der Option --enable-soap konfiguriert wurde.
 */
 
//Lizenz-Schlüssel der Applikation:
$applicationLicence = 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';

//Lizenz-Schlüssel des Mandanten:
$clientLicence = 'yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy';

//Mandanten-ID:
$clientId = 1234;

//Aus Applikations-Lizenz und Mandanten-Lizenz den Lizenzschlüssel für die Autorisierung bilden:
$licenceKey = md5($applicationLicence.$clientLicence);

//Array für die Authentifizierung bauen:
$auth = array(
    'clientId'   => $clientId,
    'licenceKey' => $licenceKey,
    'sandbox'    => true); //TRUE = Testbetrieb, FALSE = Produktivbetrieb


//Optionen für das SoapClient-Objekt:
$options = array(
    'trace'       => 1,     //so können später u.a. die Methoden __getLastRequest() und __getLastResponse() aufgerufen werden
    'compression' => true,  //Daten werden komprimiert zum Server übertragen
    'exceptions'  => true); //SOAP-Faults werden als Exception weitergereicht


//Nach der Erstellung eines SoapClient-Objekts mittels WSDL-Dokument, stehen die vom Web-Service
//angebotenen Funktionen direkt als Methoden des Objektes zur Verfügung:
$soapClient = new SoapClient('https://soap.mediafinanz.de/buergel210.wsdl', $options);

//Array mit Personen-Daten bauen:
$suspect = array(
    'firstname'   => 'Maximilian',  //Vorname
    'lastname'    => 'Mustermann',  //Nachname
    'street'      => 'Potsdamer Platz',  //Straße
    'houseNumber' => '1',           //Hausnummer
    'postcode'    => '10785',       //PLZ
    'city'        => 'Berlin', //Ort
    'dateOfBirth' => '01.12.1979'); //Geburtsdatum


//Berechtigtes Interesse für die Bonitätsabfrage:
//Mögliche Werte:
//- 1: Kreditanfrage
//- 2: Geschäftsanbahnung
//- 3: Bonitätsprüfung
//- 4: Forderung
$justification = 3;

//optionale Referenz, um die Anfrage besser zuordnen zu können
$reference = 'Schnittstellentest';

try
{
    //Web-Service - Funktion zur Übergabe einer neuen Forderung aufrufen:
    $result = $soapClient->getConCheckScore($auth, $suspect, $justification, $reference);

    //Rückgabewert auswerten:
    if (!empty($result->scoreResult))
    {
        echo "Die Bonitätsauskunft wurde erfolgreich eingeholt<br />\n";

        //Details der Auskunft ausgeben:
        echo "Score: " . $result->scoreResult->score . "<br />\n";
        echo "Erklärung: " . utf8_decode($result->scoreResult->scoreText) . "<br />\n";

        echo "Adresse: <br />\n";
        echo utf8_decode($result->scoreResult->firstname) . " ".utf8_decode($result->scoreResult->lastname) . "<br />\n";
        echo utf8_decode($result->scoreResult->address->street) . " " . $result->scoreResult->address->houseNumber . "<br />\n";
        echo $result->scoreResult->address->postcode . ' ' . utf8_decode($result->scoreResult->address->city) . "<br />\n";

        echo "Adressherkunft: <br />\n";
        utf8_decode($result->scoreResult->address->originText) . "<br />\n";

        if (isset($result->scoreResult->reference))
        {
            echo "Referenz: <br />";
            echo utf8_decode($result->scoreResult->reference) . "<br />\n";
        }

        $negativeEntries  = isset($result->scoreResult->countOfNegativeEntries)  ? $result->scoreResult->countOfNegativeEntries  : 0;
        $relatedCompanies = isset($result->scoreResult->countOfRelatedCompanies) ? $result->scoreResult->countOfRelatedCompanies : 0;

        echo "Es sind $negativeEntries Negativmerkmale verfügbar<br />\n";
        echo "Es gibt $relatedCompanies mit der Person in Beziehung stehende Firmen<br />\n";

        //Die Details der Negativmerkmale werden in diesem Demo-Skript nicht dargestellt!
    }
    else
    {
        echo "Die Bonitätsauskunft konnte nicht eingeholt werden!<br />\n";

        //alle Fehler ausgeben:
        foreach ($result->errorList as $errorMsg)
        {
        	echo "Fehler: ".$errorMsg."<br />\n";
        }

    }
}
catch (Exception $e)
{
    echo "Es ist folgender Fehler aufgetreten: " . $e->getMessage() ."<br />\n";
	
	echo "REQUEST HEADERS:<br />\n" . htmlentities($soapClient->__getLastRequestHeaders());
	echo "<br /><br />\n";
	echo "REQUEST BODY<br />\n" . htmlentities($soapClient->__getLastRequest());
	echo "<br /><br />\n";
	echo "RESPONSE HEADERS:<br />\n" . htmlentities($soapClient->__getLastResponseHeaders());
	echo "<br /><br />\n";
	echo "RESPONSE BODY<br />\n" . htmlentities($soapClient->__getLastResponse());
	echo "<br /><br />\n";
	
}