<?php
 
 /**
 * Diese Datei enthält ein Beispiel-Skript zur Abfrage von Statusänderungen Ihrer Inkasso-Forderungen mit PHP.
 * Das Skript hat lediglich exemplarischen Charakter und dient keinesfalls als vollständige Funktions-Referenz!
 * Die SOAP-Funktionalität steht nur dann zur Verfügung, wenn PHP mit der Option --enable-soap konfiguriert wurde.
 */


//Lizenz-Schlüssel der Applikation:
$applicationLicence = 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';

//Lizenz-Schlüssel des Mandanten:
$clientLicence = 'yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy';

//Mandanten-ID:
$clientId = 1234;


//Aus Applikations-Lizenz und Mandanten-Lizenz den Lizenzschlüssel für die Autorisierung bilden:
$licenceKey = md5($applicationLicence . $clientLicence);

//Array für die Authentifizierung bauen:
$auth = array(
    'clientId'   => $clientId,
    'licenceKey' => $licenceKey,
    'sandbox'    => true); //TRUE = Testbetrieb, FALSE = Produktivbetrieb

//Optionen für das SoapClient-Objekt:
$options = array(
    'trace'       => 1,     //so können später u.a. die Methoden __getLastRequest() und __getLastResponse() aufgerufen werden
    'compression' => true,  //Daten werden komprimiert zum Server übertragen
    'exceptions'  => true); //SOAP-Faults werden als Exception weitergereicht


//Nach der Erstellung eines SoapClient-Objekts mittels WSDL-Dokument, stehen die vom Web-Service
//angebotenen Funktionen direkt als Methoden des Objektes zur Verfügung:
$soapClient = new SoapClient('https://soap.mediafinanz.de/encashment210.wsdl', $options);


try
{
    //Web-Service - Funktion zur Abfrage aller Statusänderungen aufrufen:
    $result = $soapClient->getClaimStatusChanges($auth);

    //Im Rückgabewert der Funktion getClaimStatusChanges() ist eine Transaktionskennung
    //enthalten, die nach erfolgreicher Weiterverarbeitung der Statusänderungen
    //an die Funktion commitTransaction() übergeben werden muss.
    $transactionId = $result->transactionId;

	if ( !empty($result->changes) )
	{
		//alle zurückgelieferten Statusänderungen durchlaufen und ausgeben / weiterverarbeiten:
		foreach ($result->changes as $change)
		{
			echo "Aktenzeichen: "      . $change->fileNumber    . " <br />\n";
			echo "Rechnungsnr.: "      . $change->invoiceNumber . " <br />\n";
			echo "Zeitpunkt: "         . $change->time          . " <br />\n";
			echo "Status-Kennziffer: " . $change->statusCode    . " <br />\n";
			echo "Statusbezeichnung: " . $change->statusName    . " <br />\n";

			if (isset($change->closingReasonCode))
			{
				echo "Optional. Einstellungs-Kennziffer: " . $change->closingReasonCode . " <br />\n";
			}

			if (isset($change->closingReasonExplanation))
			{
				echo "Optional. Einstellungsgrund: " . $change->closingReasonExplanation . " <br />\n";
			}

			if (isset($change->closingReasonNote))
			{
				echo "Optional. Anmerkung zum Einstellungsgrund: " . $change->closingReasonNote . " <br />\n";
			}
		}
	} else {
		echo "Es liegen keine Status-Änderungen vor!";
	}

    //nach erfolgreicher Verarbeitung aller Statuswechsel-Informationen, muss die Transaktion noch
    //bestätigt werden:
    $soapClient->commitTransaction($auth, $transactionId);
}
catch (Exception $e)
{
    echo "Es ist folgender Fehler aufgetreten: " . $e->getMessage(). "<br />\n";

    echo "REQUEST HEADERS:<br />\n" . htmlentities($soapClient->__getLastRequestHeaders());
    echo "<br /><br />\n";
    echo "REQUEST BODY<br />\n" . htmlentities($soapClient->__getLastRequest());
    echo "<br /><br />\n";
    echo "RESPONSE HEADERS:<br />\n" . htmlentities($soapClient->__getLastResponseHeaders());
    echo "<br /><br />\n";
    echo "RESPONSE BODY<br />\n" . htmlentities($soapClient->__getLastResponse());
    echo "<br /><br />\n";
}